################
mididings Manual
################

mididings is a MIDI router and processor, supporting ALSA and JACK MIDI.

Homepage: https://github.com/mididings/mididings

The latest version of this manual can be found at
https://mididings.github.io/mididings/.


Contents:

.. toctree::
    start
    connect
    misc
    main
    units
    extra-units
    extra
    event
    engine
    util
    tools


Indices and Tables
==================

* :ref:`genindex`
* :ref:`search`
